Index: src/debug.cc |
diff --git a/src/debug.cc b/src/debug.cc |
index 9212b02ec33317fc590157954561b8729db2e460..3149a54a1d2ae3c48af8e2035356ba9bfbaf497e 100644 |
--- a/src/debug.cc |
+++ b/src/debug.cc |
@@ -1181,8 +1181,9 @@ void Debug::FloodHandlerWithOneShot() { |
} |
for (JavaScriptFrameIterator it(isolate_, id); !it.done(); it.Advance()) { |
JavaScriptFrame* frame = it.frame(); |
- if (frame->HasHandler()) { |
- // Flood the function with the catch block with break points |
+ int stack_slots = 0; // The computed stack slot count is not used. |
+ if (frame->LookupExceptionHandlerInTable(&stack_slots) > 0) { |
+ // Flood the function with the catch/finally block with break points. |
FloodWithOneShot(Handle<JSFunction>(frame->function())); |
return; |
} |